Django REST Search
==================

|rtd| |pypi-v| |tests| |codecov|

.. |rtd| image:: https://readthedocs.org/projects/django-rest-search/badge/?version=latest
   :target: https://django-rest-search.readthedocs.io/

.. |tests| image:: https://github.com/wemap/django-rest-search/workflows/tests/badge.svg
    :target: https://github.com/wemap/django-rest-search/actions

.. |codecov| image:: https://img.shields.io/codecov/c/github/wemap/django-rest-search.svg
    :target: https://codecov.io/gh/wemap/django-rest-search

.. |pypi-v| image:: https://img.shields.io/pypi/v/djangorestsearch.svg
    :target: https://pypi.python.org/pypi/djangorestsearch

Django REST Search provides a set of classes to facilitate the integration of
OpenSearch into applications powered by the Django REST Framework.

Full documentation for the project is available at
http://django-rest-search.readthedocs.io/.
